@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::GENEHACK;
 our $AUTHORITY = 'cpan:GENEHACK';
-$Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.6_04';
+$Dist::Zilla::PluginBundle::GENEHACK::VERSION = '0.6_05';
 # ABSTRACT: BeLike::GENEHACK when you zilla your dist
 
 
@@ -36,6 +36,7 @@ use Dist::Zilla::Plugin::Test::Compile;
 use Dist::Zilla::Plugin::Git::Tag;
 use Dist::Zilla::Plugin::Git::Commit;
 use Dist::Zilla::Plugin::InstallRelease;
+use Dist::Zilla::Plugin::Git::Push;
 use Dist::Zilla::Plugin::Twitter;
 use Dist::Zilla::Plugin::Run;
 
@@ -133,6 +134,8 @@ sub configure {
     # install dist after release
     [ 'InstallRelease' => { install_command => 'cpanm .' } ] ,
 
+    'Git::Push',
+
     # tweet releases. because i can.
     'Twitter' ,
 
@@ -168,7 +171,7 @@ Dist::Zilla::PluginBundle::GENEHACK - BeLike::GENEHACK when you zilla your dist
 
 =head1 VERSION
 
-version 0.6_04
+version 0.6_05
 
 =head1 SYNOPSIS
 
@@ -215,6 +218,7 @@ this:
     add_files_in = releases/
     [InstallRelease]
     install_command='cpanm .'
+    [Git::Push]
     [Twitter]
     [Run::BeforeBuild]
     run = rm -f Makefile.PL
